@@ -87,6 +87,10 @@ DelayedType = Callable[[ByteString], FinalType]
 MaybeDelayedType = Union[DelayedType, FinalType]
 
 
+class ParserError(ArgumentTypeError): pass
+class VariablesMissing(ParserError): pass
+
+
 class PythonExpression:
     """
     Implements a parser for any Python expression with a prescribed set of variable
@@ -147,21 +151,21 @@ class PythonExpression:
             expression = ast.parse(definition)
             nodes = ast.walk(expression)
         except Exception:
-            raise ArgumentTypeError(F'The provided expression could not be parsed: {definition!s}')
+            raise ParserError(F'The provided expression could not be parsed: {definition!s}')
         if type(next(nodes)) != ast.Module:
-            raise ArgumentTypeError(F'unknown error parsing the expression: {definition!s}')
+            raise ParserError(F'unknown error parsing the expression: {definition!s}')
         if type(next(nodes)) != ast.Expr:
-            raise ArgumentTypeError(F'not a valid Python expression: {definition!s}')
+            raise ParserError(F'not a valid Python expression: {definition!s}')
         nodes = list(nodes)
         types = set(type(node) for node in nodes)
         names = set(node.id for node in nodes if type(node) == ast.Name)
         if not types <= self._ALLOWED_NODE_TYPES:
-            raise ArgumentTypeError(
+            raise ParserError(
                 'the following operations are not allowed: {}'.format(
                     ', '.join(t.__name__ for t in types - self._ALLOWED_NODE_TYPES))
             )
         if not names <= variables:
-            raise ArgumentTypeError(
+            raise VariablesMissing(
                 'the following variable names are unknown: {}'.format(
                     ', '.join(names - variables))
             )
@@ -197,41 +201,18 @@ def sliceobj(expression: Union[int, str], **variables) -> slice:
         sliced = expression.split(':')
         if not sliced or len(sliced) > 3:
             raise ArgumentTypeError(F'the expression {expression} is not a valid slice.')
-        sliced = [None if not t else PythonExpression.evaluate(t, **variables) for t in sliced]
+        try:
+            sliced = [None if not t else PythonExpression.evaluate(t, **variables) for t in sliced]
+        except VariablesMissing:
+            class SliceAgain(LazyEvaluation):
+                def __call__(self, data): return sliceobj(expression, **data.meta)
+            return SliceAgain()
     if len(sliced) == 1:
         k = sliced[0]
         return slice(k, k + 1) if k + 1 else slice(k, None, None)
     return slice(*sliced)
 
 
-class virtualaddr:
-    """
-    Represents a virtual address; used by `refinery.peslice` and
-    `refinery.elfslice` to reference offsets in executable file
-    formats as they would appear in memory.
-    """
-    def __init__(self, address='0'):
-        try:
-            self.section, address = address.split(':')
-        except ValueError:
-            self.section = None
-        else:
-            if not address:
-                self.address = 0
-                return
-        try:
-            address = address.upper()
-            if address.endswith('H'):
-                address = F'0x{address[:-1]}'
-            self.address = number[0:](address)
-        except Exception:
-            pass
-        try:
-            self.address = number(F'0x{address}')
-        except ValueError:
-            raise ArgumentTypeError(F'could not parse {address} as hexadecimal integer')
-
-
 def utf8(x):
     """
     Returns the UTF8 encoding of the given string.
@@ -805,7 +786,9 @@ class DelayedNumberArgument(DelayedArgument):
         """
         The default handler: Attempts to parse the input expression as an integer.
         """
-        def parse(b):
+        def parse(b: Union[int, ByteString]) -> int:
+            if isinstance(b, int):
+                return b
             expression = PythonExpression(b.decode('utf8'))
             t = expression()
             if self.bin and not isinstance(t, int):
@@ -823,6 +806,10 @@ class DelayedNumberArgument(DelayedArgument):
         def le(b: ByteString): return int.from_bytes(b, 'little')
         return self._mbin(le, expression)
 
+    @handler.register('h', 'H', final=True)
+    def hex(self, expression: str) -> int:
+        return int(expression.upper().rstrip('H'), 16)
+
 
 class number:
     __name__ = 'number'
@@ -837,10 +824,17 @@ class number:
     def __call__(self, value):
         if isinstance(value, int):
             return value
-        value = DelayedNumberArgument(value, self.min, self.max)
-        with suppress(TooLazy):
-            return value()
-        return value
+        try:
+            delay = DelayedNumberArgument(value, self.min, self.max)
+            return delay()
+        except TooLazy:
+            return delay
+        except ParserError:
+            import re
+            match = re.fullmatch('(?:0x)?([A-F0-9]+)H?', value, flags=re.IGNORECASE)
+            if not match:
+                raise
+            return number(F'0x{match[1]}')
 
 
 number = number()
