@@ -165,18 +165,24 @@ class arg(Argument):
     def update_help(self):
         if 'help' not in self.kwargs:
             return
-        formatting = {}
-        choices = self.kwargs.get('choices', None)
-        if choices is not None:
-            formatting.update(choices=', '.join(self.kwargs['choices']))
-        default = self.kwargs.get('default', None)
-        if default is not None:
-            try:
-                formatting.update(default=F'H:{default.hex()}')
-            except AttributeError:
-                formatting.update(default=str(default))
+
+        class formatting(dict):
+            arg = self
+
+            def __missing__(self, key):
+                if key == 'choices':
+                    return ', '.join(self.arg.kwargs['choices'])
+                if key == 'default':
+                    default = self.arg.kwargs['default']
+                    if isbuffer(default):
+                        return F'H:{default.hex()}'
+                    return str(default)
+                if key == 'varname':
+                    return self.arg.kwargs.get('metavar', self.arg.destination)
+
         try:
-            self.kwargs['help'] = self.kwargs['help'].format(**formatting)
+            self.kwargs.update(
+                help=self.kwargs['help'].format_map(formatting()))
         except Exception:
             pass
 
@@ -184,6 +190,22 @@ class arg(Argument):
         self.update_help()
         return super().__rmatmul__(method)
 
+    @staticmethod
+    def as_option(value: Optional[Any], cls: Enum) -> Enum:
+        if value is None or isinstance(value, cls):
+            return value
+        if isinstance(value, str):
+            try: return cls[value]
+            except KeyError: pass
+            needle = value.upper()
+            for item in cls:
+                if item.name.upper() == needle:
+                    return item
+        try:
+            return cls(value)
+        except Exception as E:
+            raise ValueError(F'Could not transform {value} into a {cls.__name__}.') from E
+
     @staticmethod
     def switch(
         *args: str, off=False,
@@ -409,6 +431,41 @@ class ArgumentSpecification(OrderedDict):
         self[dest] = argument
 
 
+def UnitProcessorBoilerplate(
+    operation: Callable[[Any, ByteString], Any]
+) -> Callable[[ByteString], Any]:
+    @wraps(operation)
+    def wrapped(self, data: ByteString) -> Union[Optional[ByteString], Iterable[ByteString]]:
+        data = self.args @ data
+        typespec = get_type_hints(operation)
+        typespec.pop('return', None)
+        if typespec:
+            assert len(typespec) == 1
+            dt = next(iter(typespec.values()))
+            if isinstance(dt, type) and not isinstance(data, dt):
+                data = dt(data)
+        if wrapped.chunked:
+            return (self.labelled(r) for r in operation(self, data))
+        return self.labelled(operation(self, data))
+    wrapped.chunked = inspect.isgeneratorfunction(operation)
+    return wrapped
+
+
+def UnitFilterBoilerplate(
+    operation : Callable[[Any, Iterable[Chunk]], Iterable[Chunk]]
+) -> Callable[[Any, Iterable[Chunk]], Iterable[Chunk]]:
+    @wraps(operation)
+    def peekfilter(self, chunks: Iterable[Chunk]) -> Iterable[Chunk]:
+        def rewind(*head):
+            yield from head
+            yield from it
+        it = iter(chunks)
+        for head in it:
+            yield from operation(self, rewind(self.args @ head))
+            break
+    return peekfilter
+
+
 class Executable(type):
     """
     This is the metaclass for refinery units. A class which is of this type is
@@ -477,35 +534,19 @@ class Executable(type):
         return args
 
     def __new__(mcs, name, bases, nmspc, abstract=False):
-        def normalize(operation: Callable[[Any, ByteString], Any]) -> Callable[[ByteString], Any]:
-            @wraps(operation)
-            def wrapped(self, data: ByteString) -> Union[Optional[ByteString], Iterable[ByteString]]:
-                data = self.args @ data
-                typespec = get_type_hints(operation)
-                typespec.pop('return', None)
-                if typespec:
-                    assert len(typespec) == 1
-                    dt = next(iter(typespec.values()))
-                    if isinstance(dt, type) and not isinstance(data, dt):
-                        data = dt(data)
-                if wrapped.chunked:
-                    return (self.labelled(r) for r in operation(self, data))
-                return self.labelled(operation(self, data))
-            wrapped.chunked = inspect.isgeneratorfunction(operation)
-            return wrapped
-
+        def decorate(**decorations):
+            for method, decorator in decorations.items():
+                try: nmspc[method] = decorator(nmspc[method])
+                except KeyError: pass
+        decorate(
+            filter=UnitFilterBoilerplate,
+            process=UnitProcessorBoilerplate,
+            reverse=UnitProcessorBoilerplate,
+            __init__=no_type_check
+        )
         nmspc.setdefault('__doc__', '')
-
-        try: nmspc['__init__'] = no_type_check(nmspc['__init__'])
-        except KeyError: pass
-
-        for op in ('process', 'reverse'):
-            if op in nmspc:
-                nmspc[op] = normalize(nmspc[op])
-
         if not abstract and Entry not in bases:
             bases = bases + (Entry,)
-
         return super(Executable, mcs).__new__(mcs, name, bases, nmspc)
 
     def __init__(cls, name, bases, nmspc, abstract=False):
