@@ -19,7 +19,7 @@ class url(Unit):
     def process(self, data):
         data = re.sub(
             B'\\%([0-9a-fA-F]{2})',
-            lambda m: bytes((int(m.group(1), 16),)),
+            lambda m: bytes((int(m[1], 16),)),
             data
         )
         if self.args.plus:
@@ -31,7 +31,7 @@ class url(Unit):
             data = data.replace(B' ', B'+')
         data = re.sub(
             B'[^a-zA-Z0-9_.-~\\/]',
-            lambda m: B'%%%02X' % ord(m.group(0)),
+            lambda m: B'%%%02X' % ord(m[0]),
             data
         )
         return data
