@@ -12,7 +12,6 @@ from zlib import adler32
 from typing import ByteString, Iterable, Callable, Union
 
 from .. import arg, Unit
-from ...lib.argformats import virtualaddr
 from ...lib.tools import isbuffer
 
 
@@ -141,35 +140,3 @@ class PathExtractorUnit(Unit, abstract=True):
                 else:
                     self.log_info(path)
                 yield self.labelled(result.get_data(), path=path)
-
-
-class MemoryExtractorUnit(Unit, abstract=True):
-
-    def __init__(
-        self,
-        offset: arg(type=virtualaddr,
-            help='Specify virtual offset as either .section:OFFSET or just a virtual address in hex.'),
-        count : arg.number(metavar='count', help='The maximum number of bytes to read.') = 0,
-        utf16 : arg.switch('-u', group='END', help='Read the memory at the given offset as an UTF16 string.') = False,
-        ascii : arg.switch('-a', group='END', help='Read the memory at the given offset as an ASCII string.') = False,
-    ):
-        if utf16 and ascii:
-            raise ValueError('Only one of utf16 and ascii may be specified.')
-        return self.superinit(super(), **vars())
-
-    def _read_from_memory(self, data, offset_oracle):
-        start, end = offset_oracle(self.args.offset)
-        if self.args.ascii:
-            end = data.find(B'\0', start)
-            if end < 0:
-                raise EndOfStringNotFound
-        elif self.args.utf16:
-            for end in range(start, len(data), 2):
-                if not data[end] and not data[end + 1]:
-                    break
-            else:
-                raise EndOfStringNotFound
-        if self.args.count:
-            lbound = start + self.args.count
-            end = lbound if end is None else min(end, lbound)
-        return data[start:end]
